@@ -65,8 +65,8 @@ void MPEG4ESVideoRTPSink
   if (fragmentationOffset == 0) {
     // Begin by inspecting the 4-byte code at the start of the frame:
     if (numBytesInFrame < 4) return; // shouldn't happen
-    unsigned startCode = (frameStart[0]<<24) | (frameStart[1]<<16)
-      | (frameStart[2]<<8) | frameStart[3];
+    u_int32_t startCode
+      = (frameStart[0]<<24) | (frameStart[1]<<16) | (frameStart[2]<<8) | frameStart[3];
 
     fVOPIsPresent = startCode == VOP_START_CODE;
   }
